import * as squint_core from 'squint-cljs/core.js';
import * as lz_tree from '@lezer/common';
import * as lezer_markdown from '@lezer/markdown';
import * as language from '@codemirror/language';
import * as lezer_clj from '@nextjournal/lezer-clojure';
import * as u from './util.mjs';
import * as sel from './selections.mjs';
var coll_prop = lezer_clj.props.coll;
var prefix_coll_prop = lezer_clj.props.prefixColl;
var prefix_edge_prop = lezer_clj.props.prefixEdge;
var prefix_container_prop = lezer_clj.props.prefixContainer;
var start_edge_prop = lz_tree.NodeProp.closedBy;
var end_edge_prop = lz_tree.NodeProp.openedBy;
var same_edge_prop = lezer_clj.props.sameEdge;
var node_prop = (function (prop_name) {
let G__2221 = prop_name;
switch (G__2221) {case "prefixColl":
return prefix_coll_prop
break;
case "coll":
return coll_prop
break;
case "prefixEdge":
return prefix_edge_prop
break;
case "prefixContainer":
return prefix_container_prop
break;
case "sameEdge":
return same_edge_prop
break;
default:
throw new Error(squint_core.str("No matching clause: ", G__2221))}
});
var type = (function (node) {
return node.type
});
var start = (function (node) {
if (squint_core.truth_(node.from)) {
null} else {
throw new Error("Assert failed: (.-from node)")};
return node.from
});
var end = (function (node) {
if (squint_core.truth_(node.to)) {
null} else {
throw new Error("Assert failed: (.-to node)")};
return node.to
});
var up = (function (node) {
return node.parent
});
var down = (function (node) {
if (squint_core.not(squint_core.fn_QMARK_(node.lastChild))) {
null} else {
throw new Error("Assert failed: (not (fn? (.-lastChild node)))")};
return node.firstChild
});
var down_last = (function (node) {
if (squint_core.not(squint_core.fn_QMARK_(node.lastChild))) {
null} else {
throw new Error("Assert failed: (not (fn? (.-lastChild node)))")};
return node.lastChild
});
var depth = (function (node) {
let node1 = node;
let i2 = 0;
while(true){
let temp__27139__auto__3 = up(node1);
if ((temp__27139__auto__3 == null)) {
return i2} else {
let parent4 = temp__27139__auto__3;
let G__5 = parent4;
let G__6 = (i2 + 1);
node1 = G__5;
i2 = G__6;
continue;
};break;
}

});
var left = (function (node) {
return up(node).childBefore(start(node))
});
var lefts = (function (node) {
return squint_core.take_while(squint_core.identity, squint_core.iterate(left, left(node)))
});
var right = (function (node) {
return up(node).childAfter(end(node))
});
var rights = (function (node) {
return squint_core.take_while(squint_core.identity, squint_core.iterate(right, right(node)))
});
var coll_type_QMARK_ = (function (node_type) {
return node_type.prop(coll_prop)
});
var prefix_type_QMARK_ = (function (node_type) {
return node_type.prop(prefix_coll_prop)
});
var prefix_edge_type_QMARK_ = (function (node_type) {
return node_type.prop(prefix_edge_prop)
});
var prefix_container_type_QMARK_ = (function (node_type) {
return node_type.prop(prefix_container_prop)
});
var same_edge_type_QMARK_ = (function (node_type) {
return node_type.prop(same_edge_prop)
});
var start_edge_type_QMARK_ = (function (node_type) {
return node_type.prop(start_edge_prop)
});
var end_edge_type_QMARK_ = (function (node_type) {
return node_type.prop(end_edge_prop)
});
var top_type_QMARK_ = (function (node_type) {
return node_type.isTop
});
var error_type_QMARK_ = (function (node_type) {
return node_type.isError
});
var prefix_QMARK_ = (function (n) {
return prefix_type_QMARK_(type(n))
});
var prefix_edge_QMARK_ = (function (n) {
return prefix_edge_type_QMARK_(type(n))
});
var prefix_container_QMARK_ = (function (n) {
return prefix_container_type_QMARK_(type(n))
});
var same_edge_QMARK_ = (function (n) {
return same_edge_type_QMARK_(type(n))
});
var start_edge_QMARK_ = (function (n) {
return start_edge_type_QMARK_(type(n))
});
var end_edge_QMARK_ = (function (n) {
return end_edge_type_QMARK_(type(n))
});
var left_edge_type_QMARK_ = (function (t) {
let or__27578__auto__1 = start_edge_type_QMARK_(t);
if (squint_core.truth_(or__27578__auto__1)) {
return or__27578__auto__1} else {
let or__27578__auto__2 = same_edge_type_QMARK_(t);
if (squint_core.truth_(or__27578__auto__2)) {
return or__27578__auto__2} else {
return prefix_edge_type_QMARK_(t)}}
});
var left_edge_QMARK_ = (function (n) {
return left_edge_type_QMARK_(type(n))
});
var right_edge_type_QMARK_ = (function (t) {
let or__27578__auto__1 = end_edge_type_QMARK_(t);
if (squint_core.truth_(or__27578__auto__1)) {
return or__27578__auto__1} else {
return same_edge_type_QMARK_(t)}
});
var right_edge_QMARK_ = (function (n) {
return right_edge_type_QMARK_(type(n))
});
var edge_QMARK_ = (function (n) {
let t1 = type(n);
let or__27578__auto__2 = start_edge_type_QMARK_(t1);
if (squint_core.truth_(or__27578__auto__2)) {
return or__27578__auto__2} else {
let or__27578__auto__3 = end_edge_type_QMARK_(t1);
if (squint_core.truth_(or__27578__auto__3)) {
return or__27578__auto__3} else {
let or__27578__auto__4 = same_edge_type_QMARK_(t1);
if (squint_core.truth_(or__27578__auto__4)) {
return or__27578__auto__4} else {
return prefix_type_QMARK_(t1)}}}
});
var closed_by = (function (n) {
let G__2231 = type(n).prop(lz_tree.NodeProp.closedBy);
if ((G__2231 == null)) {
return null} else {
return G__2231[0]}
});
var opened_by = (function (n) {
let G__2241 = type(n).prop(lz_tree.NodeProp.openedBy);
if ((G__2241 == null)) {
return null} else {
return G__2241[0]}
});
var name = (function (node) {
return node.name
});
var error_QMARK_ = (function (node) {
return error_type_QMARK_(node)
});
var top_QMARK_ = (function (node) {
return top_type_QMARK_(type(node))
});
var program_QMARK_ = (function (node) {
return squint_core.identical_QMARK_("Program", name(node))
});
var string_QMARK_ = (function (node) {
return squint_core.identical_QMARK_("String", name(node))
});
var regexp_QMARK_ = (function (node) {
return squint_core.identical_QMARK_("RegExp", name(node))
});
var line_comment_QMARK_ = (function (node) {
return squint_core.identical_QMARK_("LineComment", name(node))
});
var discard_QMARK_ = (function (node) {
return squint_core.identical_QMARK_("Discard", name(node))
});
null;
var coll_QMARK_ = (function (node) {
return coll_type_QMARK_(type(node))
});
var terminal_type_QMARK_ = (function (node_type) {
if (squint_core.truth_(top_type_QMARK_(node_type))) {
return false} else {
if (squint_core.truth_(node_type.prop(prefix_coll_prop))) {
return false} else {
if (squint_core.truth_(node_type.prop(coll_prop))) {
return false} else {
if (squint_core.truth_(squint_core.identical_QMARK_("Meta", name(node_type)))) {
return false} else {
if (squint_core.truth_(squint_core.identical_QMARK_("TaggedLiteral", name(node_type)))) {
return false} else {
if (squint_core.truth_(squint_core.identical_QMARK_("ConstructorCall", name(node_type)))) {
return false} else {
if ("else") {
return true} else {
return null}}}}}}}
});
var balanced_QMARK_ = (function (p__225) {
let map__12 = p__225;
let _node3 = map__12;
let firstChild4 = squint_core.get(map__12, "firstChild");
let lastChild5 = squint_core.get(map__12, "lastChild");
let temp__27107__auto__6 = closed_by(firstChild4);
if (squint_core.truth_(temp__27107__auto__6)) {
let closing7 = temp__27107__auto__6;
let and__27607__auto__8 = (closing7 === name(lastChild5));
if (and__27607__auto__8) {
return (end(firstChild4) !== end(lastChild5))} else {
return and__27607__auto__8}} else {
return true}
});
var ancestors = (function (node) {
let temp__27298__auto__1 = up(node);
if ((temp__27298__auto__1 == null)) {
return null} else {
let parent2 = temp__27298__auto__1;
return squint_core.cons(parent2, new squint_core.LazySeq((function () {
return ancestors(parent2)
})))}
});
var closest = (function (node, pred) {
if (squint_core.truth_(pred(node))) {
return node} else {
return squint_core.reduce((function (_, x) {
if (squint_core.truth_(pred(x))) {
return squint_core.reduced(x)}
}), null, ancestors(node))}
});
var highest = (function (node, pred) {
return squint_core.reduce((function (found, x) {
if (squint_core.truth_(pred(x))) {
return x} else {
return squint_core.reduced(found)}
}), null, squint_core.cons(node, ancestors(node)))
});
var children = (function () {
 let f226 = (function (var_args) {
let G__2291 = arguments.length;
switch (G__2291) {case 3:
return f226.cljs$core$IFn$_invoke$arity$3((arguments[0]), (arguments[1]), (arguments[2]))
break;
case 1:
return f226.cljs$core$IFn$_invoke$arity$1((arguments[0]))
break;
default:
throw new Error(squint_core.str("Invalid arity: ", squint_core.alength(arguments)))}
});
f226.cljs$core$IFn$_invoke$arity$3 = (function (parent, from, dir) {
let temp__27298__auto__3 = (function () {
 let G__2304 = dir;
switch (G__2304) {case 1:
return parent.childAfter(from)
break;
case -1:
return parent.childBefore(from)
break;
default:
throw new Error(squint_core.str("No matching clause: ", G__2304))}
})();
if ((temp__27298__auto__3 == null)) {
return null} else {
let child6 = temp__27298__auto__3;
return squint_core.cons(child6, new squint_core.LazySeq((function () {
return children(parent, (function () {
 let G__2317 = dir;
switch (G__2317) {case 1:
return end(child6)
break;
case -1:
return start(child6)
break;
default:
throw new Error(squint_core.str("No matching clause: ", G__2317))}
})(), dir)
})))}
});
f226.cljs$core$IFn$_invoke$arity$1 = (function (subtree) {
return children(subtree, start(subtree), 1)
});
f226.cljs$lang$maxFixedArity = 3;
return f226
})();
var eq_QMARK_ = (function (x, y) {
let and__27607__auto__1 = (start(x) == start(y));
if (and__27607__auto__1) {
let and__27607__auto__2 = (end(x) == end(y));
if (and__27607__auto__2) {
return (depth(x) == depth(y))} else {
return and__27607__auto__2}} else {
return and__27607__auto__1}
});
var empty_QMARK_ = (function (node) {
let type_name1 = name(node);
if (squint_core.truth_(coll_QMARK_(node))) {
return eq_QMARK_(right(down(node)), down_last(node))} else {
if (("String" === type_name1)) {
return (end(down(node)) == start(down_last(node)))} else {
if ("else") {
return false} else {
return null}}}
});
var from_to = (function () {
 let f232 = (function (var_args) {
let G__2351 = arguments.length;
switch (G__2351) {case 2:
return f232.cljs$core$IFn$_invoke$arity$2((arguments[0]), (arguments[1]))
break;
case 1:
return f232.cljs$core$IFn$_invoke$arity$1((arguments[0]))
break;
default:
throw new Error(squint_core.str("Invalid arity: ", squint_core.alength(arguments)))}
});
f232.cljs$core$IFn$_invoke$arity$2 = (function (from, to) {
return ({ "from": from, "to": to })
});
f232.cljs$core$IFn$_invoke$arity$1 = (function (node) {
return from_to(start(node), end(node))
});
f232.cljs$lang$maxFixedArity = 2;
return f232
})();
var range = (function (node) {
return sel.range(start(node), end(node))
});
var string = (function () {
 let f236 = (function (var_args) {
let G__2391 = arguments.length;
switch (G__2391) {case 2:
return f236.cljs$core$IFn$_invoke$arity$2((arguments[0]), (arguments[1]))
break;
case 3:
return f236.cljs$core$IFn$_invoke$arity$3((arguments[0]), (arguments[1]), (arguments[2]))
break;
default:
throw new Error(squint_core.str("Invalid arity: ", squint_core.alength(arguments)))}
});
f236.cljs$core$IFn$_invoke$arity$2 = (function (state, node) {
return string(state, start(node), end(node))
});
f236.cljs$core$IFn$_invoke$arity$3 = (function (state, from, to) {
return state.doc.sliceString(from, to, "\n")
});
f236.cljs$lang$maxFixedArity = 3;
return f236
})();
var ancestor_QMARK_ = (function (parent, child) {
return squint_core.boolean$((function () {
 let and__27607__auto__1 = (start(parent) <= start(child));
if (and__27607__auto__1) {
let and__27607__auto__2 = (end(parent) >= end(child));
if (and__27607__auto__2) {
return (depth(parent) < depth(child))} else {
return and__27607__auto__2}} else {
return and__27607__auto__1}
})())
});
var move_toward = (function (node, to_node) {
if (squint_core.truth_(eq_QMARK_(node, to_node))) {
return null} else {
let G__2401 = squint_core.compare(start(to_node), start(node));
switch (G__2401) {case 0:
if (squint_core.truth_(ancestor_QMARK_(to_node, node))) {
return up(node)} else {
if (squint_core.truth_(ancestor_QMARK_(node, to_node))) {
return down(node)} else {
return null}}
break;
case -1:
if (squint_core.truth_(ancestor_QMARK_(node, to_node))) {
return down_last(node)} else {
let or__27578__auto__3 = left(node);
if (squint_core.truth_(or__27578__auto__3)) {
return or__27578__auto__3} else {
return up(node)}}
break;
case 1:
if (squint_core.truth_(ancestor_QMARK_(node, to_node))) {
return down(node)} else {
let or__27578__auto__4 = right(node);
if (squint_core.truth_(or__27578__auto__4)) {
return or__27578__auto__4} else {
return up(node)}}
break;
default:
throw new Error(squint_core.str("No matching clause: ", G__2401))}}
});
var nodes_between = (function (node, to_node) {
return squint_core.take_while(squint_core.identity, squint_core.iterate((function (_PERCENT_1) {
return move_toward(_PERCENT_1, to_node)
}), node))
});
var require_balance_QMARK_ = (function (node) {
let or__27578__auto__1 = coll_QMARK_(node);
if (squint_core.truth_(or__27578__auto__1)) {
return or__27578__auto__1} else {
let or__27578__auto__2 = string_QMARK_(node);
if (squint_core.truth_(or__27578__auto__2)) {
return or__27578__auto__2} else {
return regexp_QMARK_(node)}}
});
var tree = (function () {
 let f241 = (function (var_args) {
let G__2441 = arguments.length;
switch (G__2441) {case 1:
return f241.cljs$core$IFn$_invoke$arity$1((arguments[0]))
break;
case 2:
return f241.cljs$core$IFn$_invoke$arity$2((arguments[0]), (arguments[1]))
break;
case 3:
return f241.cljs$core$IFn$_invoke$arity$3((arguments[0]), (arguments[1]), (arguments[2]))
break;
default:
throw new Error(squint_core.str("Invalid arity: ", squint_core.alength(arguments)))}
});
f241.cljs$core$IFn$_invoke$arity$1 = (function (state) {
return language.syntaxTree(state)
});
f241.cljs$core$IFn$_invoke$arity$2 = (function (state, pos) {
return language.syntaxTree(state).resolveInner(pos)
});
f241.cljs$core$IFn$_invoke$arity$3 = (function (state, pos, dir) {
return language.syntaxTree(state).resolveInner(pos, dir)
});
f241.cljs$lang$maxFixedArity = 3;
return f241
})();
var cursor = (function () {
 let f245 = (function (var_args) {
let G__2481 = arguments.length;
switch (G__2481) {case 1:
return f245.cljs$core$IFn$_invoke$arity$1((arguments[0]))
break;
case 2:
return f245.cljs$core$IFn$_invoke$arity$2((arguments[0]), (arguments[1]))
break;
case 3:
return f245.cljs$core$IFn$_invoke$arity$3((arguments[0]), (arguments[1]), (arguments[2]))
break;
default:
throw new Error(squint_core.str("Invalid arity: ", squint_core.alength(arguments)))}
});
f245.cljs$core$IFn$_invoke$arity$1 = (function (tree) {
return tree.cursor()
});
f245.cljs$core$IFn$_invoke$arity$2 = (function (tree, pos) {
return tree.cursorAt(pos)
});
f245.cljs$core$IFn$_invoke$arity$3 = (function (tree, pos, dir) {
return tree.cursorAt(pos, dir)
});
f245.cljs$lang$maxFixedArity = 3;
return f245
})();
var terminal_cursor = (function (tree, pos, dir) {
let i1 = pos;
while(true){
let c2 = cursor(tree, i1, dir);
let type3 = c2.type;
if (squint_core.truth_(top_type_QMARK_(type3))) {
return null} else {
if (squint_core.truth_(terminal_type_QMARK_(c2.type))) {
return c2} else {
if ("else") {
let G__4 = (dir + i1);
i1 = G__4;
continue;
} else {
return null}}};break;
}

});
var up_here = (function (node) {
let from1 = start(node);
let or__27578__auto__2 = highest(node, (function (_PERCENT_1) {
return (from1 === start(_PERCENT_1))
}));
if (squint_core.truth_(or__27578__auto__2)) {
return or__27578__auto__2} else {
return node}
});
var topmost_cursor = (function (state, from) {
return up_here(tree(state, from, 1).node).cursor()
});
var terminal_nodes = (function (state, from, to) {
let cursor1 = topmost_cursor(state, from);
let found2 = [];
while(true){
let node_type3 = type(cursor1);
if ((start(cursor1) > to)) {
return found2} else {
if (squint_core.truth_((function () {
 let or__27578__auto__4 = terminal_type_QMARK_(node_type3);
if (squint_core.truth_(or__27578__auto__4)) {
return or__27578__auto__4} else {
return error_QMARK_(node_type3)}
})())) {
let found5 = squint_core.conj(found2, ({ "type": node_type3, "from": start(cursor1), "to": end(cursor1) }));
cursor1.lastChild();
if (squint_core.truth_(cursor1.next())) {
let G__6 = found5;
found2 = G__6;
continue;
} else {
return found5}} else {
if ("else") {
if (squint_core.truth_(cursor1.next())) {
let G__7 = found2;
found2 = G__7;
continue;
} else {
return found2}} else {
return null}}};break;
}

});
var balanced_range = (function () {
 let f249 = (function (var_args) {
let G__2521 = arguments.length;
switch (G__2521) {case 2:
return f249.cljs$core$IFn$_invoke$arity$2((arguments[0]), (arguments[1]))
break;
case 3:
return f249.cljs$core$IFn$_invoke$arity$3((arguments[0]), (arguments[1]), (arguments[2]))
break;
default:
throw new Error(squint_core.str("Invalid arity: ", squint_core.alength(arguments)))}
});
f249.cljs$core$IFn$_invoke$arity$2 = (function (state, node) {
return balanced_range(state, start(node), end(node))
});
f249.cljs$core$IFn$_invoke$arity$3 = (function (state, from, to) {
let vec__39 = squint_core.sort([from, to]);
let from10 = squint_core.nth(vec__39, 0, null);
let to11 = squint_core.nth(vec__39, 1, null);
let from_node12 = tree(state, from10, 1);
let to_node13 = tree(state, to11, -1);
let from14 = (squint_core.truth_(require_balance_QMARK_(from_node12))) ? (start(from_node12)) : (from10);
let to15 = (squint_core.truth_(require_balance_QMARK_(to_node13))) ? (end(to_node13)) : (to11);
let vec__616 = squint_core.reduce((function (p__253, node_between) {
let vec__1720 = p__253;
let left21 = squint_core.nth(vec__1720, 0, null);
let right22 = squint_core.nth(vec__1720, 1, null);
return [(squint_core.truth_(ancestor_QMARK_(node_between, from_node12))) ? (start(node_between)) : (left21), (squint_core.truth_(ancestor_QMARK_(node_between, to_node13))) ? (end(node_between)) : (right22)]
}), [from14, to15], squint_core.map((function (_PERCENT_1) {
let G__25423 = _PERCENT_1;
if (squint_core.truth_(edge_QMARK_(_PERCENT_1))) {
return up(G__25423)} else {
return G__25423}
}), nodes_between(from_node12, to_node13)));
let left24 = squint_core.nth(vec__616, 0, null);
let right25 = squint_core.nth(vec__616, 1, null);
return sel.range(left24, right25)
});
f249.cljs$lang$maxFixedArity = 3;
return f249
})();
var inner_span = (function (p__255) {
let map__12 = p__255;
let node3 = map__12;
let firstChild4 = squint_core.get(map__12, "firstChild");
let lastChild5 = squint_core.get(map__12, "lastChild");
return ({ "from": (squint_core.truth_(left_edge_QMARK_(firstChild4))) ? (end(firstChild4)) : (start(node3)), "to": (squint_core.truth_(right_edge_QMARK_(lastChild5))) ? (start(lastChild5)) : (end(node3)) })
});
var within_QMARK__LT_ = (function (parent, child) {
let c11 = squint_core.compare(start(parent), start(child));
let c22 = squint_core.compare(end(parent), end(child));
let and__27607__auto__3 = (function () {
 let or__27578__auto__4 = (c11 > 0);
if (or__27578__auto__4) {
return or__27578__auto__4} else {
return (c22 < 0)}
})();
if (squint_core.truth_(and__27607__auto__3)) {
let and__27607__auto__5 = !(c11 < 0);
if (and__27607__auto__5) {
return !(c22 > 0)} else {
return and__27607__auto__5}} else {
return and__27607__auto__3}
});
var within_QMARK_ = (function (parent, child) {
let and__27607__auto__1 = !(squint_core.compare(start(parent), start(child)) < 0);
if (and__27607__auto__1) {
return !(squint_core.compare(end(parent), end(child)) > 0)} else {
return and__27607__auto__1}
});
var follow_edges = (function (node) {
if (squint_core.truth_(edge_QMARK_(node))) {
return up(node)} else {
return node}
});
var prefix = (function (node) {
let temp__27298__auto__1 = up(node);
if ((temp__27298__auto__1 == null)) {
return null} else {
let parent2 = temp__27298__auto__1;
let or__27578__auto__3 = u.guard(parent2, prefix_container_QMARK_);
if (squint_core.truth_(or__27578__auto__3)) {
return or__27578__auto__3} else {
return u.guard(down(parent2), prefix_edge_QMARK_)}}
});
var left_edge_with_prefix = (function (state, node) {
return squint_core.str((function () {
 let G__2561 = prefix(node);
if ((G__2561 == null)) {
return null} else {
return string(state, G__2561)}
})(), name(down(node)))
});
var with_prefix = (function (node) {
let G__2571 = node;
if (squint_core.truth_(prefix(node))) {
return up(G__2571)} else {
return G__2571}
});
var node_BAR_ = (function (state, pos) {
let G__2581 = tree(state, pos, -1);
if ((G__2581 == null)) {
return null} else {
return u.guard(G__2581, (function (_PERCENT_1) {
return (pos === end(_PERCENT_1))
}))}
});
var _BAR_node = (function (state, pos) {
let G__2591 = tree(state, pos, 1);
if ((G__2591 == null)) {
return null} else {
return u.guard(G__2591, (function (_PERCENT_1) {
return (pos === start(_PERCENT_1))
}))}
});
var nearest_touching = (function (state, pos, dir) {
let L1 = (function () {
 let G__2602 = tree(state, pos, -1);
if ((G__2602 == null)) {
return null} else {
return u.guard(G__2602, (function (p__261) {
let map__34 = p__261;
let to5 = squint_core.get(map__34, "to");
return (pos === to5)
}))}
})();
let R6 = (function () {
 let G__2627 = tree(state, pos, 1);
if ((G__2627 == null)) {
return null} else {
return u.guard(G__2627, (function (p__263) {
let map__89 = p__263;
let from10 = squint_core.get(map__89, "from");
return (pos === from10)
}))}
})();
let mid11 = tree(state, pos);
let G__26412 = dir;
switch (G__26412) {case 1:
let or__27578__auto__14 = u.guard(R6, squint_core.every_pred(squint_core.some_QMARK_, (function (_PERCENT_1) {
let or__27578__auto__15 = same_edge_QMARK_(_PERCENT_1);
if (squint_core.truth_(or__27578__auto__15)) {
return or__27578__auto__15} else {
return squint_core.not(right_edge_QMARK_(_PERCENT_1))}
})));
if (squint_core.truth_(or__27578__auto__14)) {
return or__27578__auto__14} else {
let or__27578__auto__16 = L1;
if (squint_core.truth_(or__27578__auto__16)) {
return or__27578__auto__16} else {
let or__27578__auto__17 = R6;
if (squint_core.truth_(or__27578__auto__17)) {
return or__27578__auto__17} else {
return mid11}}}
break;
case -1:
let or__27578__auto__18 = u.guard(L1, squint_core.every_pred(squint_core.some_QMARK_, (function (_PERCENT_1) {
let or__27578__auto__19 = same_edge_QMARK_(_PERCENT_1);
if (squint_core.truth_(or__27578__auto__19)) {
return or__27578__auto__19} else {
return squint_core.not(left_edge_QMARK_(_PERCENT_1))}
})));
if (squint_core.truth_(or__27578__auto__18)) {
return or__27578__auto__18} else {
let or__27578__auto__20 = R6;
if (squint_core.truth_(or__27578__auto__20)) {
return or__27578__auto__20} else {
let or__27578__auto__21 = L1;
if (squint_core.truth_(or__27578__auto__21)) {
return or__27578__auto__21} else {
return mid11}}}
break;
default:
throw new Error(squint_core.str("No matching clause: ", G__26412))}
});
var embedded_QMARK_ = (function () {
 let f265 = (function (var_args) {
let G__2681 = arguments.length;
switch (G__2681) {case 1:
return f265.cljs$core$IFn$_invoke$arity$1((arguments[0]))
break;
case 2:
return f265.cljs$core$IFn$_invoke$arity$2((arguments[0]), (arguments[1]))
break;
default:
throw new Error(squint_core.str("Invalid arity: ", squint_core.alength(arguments)))}
});
f265.cljs$core$IFn$_invoke$arity$1 = (function (state) {
return embedded_QMARK_(state, state.selection.main.head)
});
f265.cljs$core$IFn$_invoke$arity$2 = (function (state, pos) {
return squint_core.identical_QMARK_(lezer_markdown.parser.nodeTypes.FencedCode, state.tree.resolve(pos).type.id)
});
f265.cljs$lang$maxFixedArity = 2;
return f265
})();
var within_program_QMARK_ = (function () {
 let f269 = (function (var_args) {
let G__2721 = arguments.length;
switch (G__2721) {case 1:
return f269.cljs$core$IFn$_invoke$arity$1((arguments[0]))
break;
case 2:
return f269.cljs$core$IFn$_invoke$arity$2((arguments[0]), (arguments[1]))
break;
default:
throw new Error(squint_core.str("Invalid arity: ", squint_core.alength(arguments)))}
});
f269.cljs$core$IFn$_invoke$arity$1 = (function (state) {
return within_program_QMARK_(state, state.selection.main.head)
});
f269.cljs$core$IFn$_invoke$arity$2 = (function (state, pos) {
let n3 = tree(state, pos);
let or__27578__auto__4 = program_QMARK_(n3);
if (squint_core.truth_(or__27578__auto__4)) {
return or__27578__auto__4} else {
return squint_core.some(program_QMARK_, ancestors(n3))}
});
f269.cljs$lang$maxFixedArity = 2;
return f269
})();
null;

export { end_edge_prop, ancestors, range, string_QMARK_, within_QMARK__LT_, edge_QMARK_, right, terminal_nodes, string, same_edge_type_QMARK_, up, line_comment_QMARK_, prefix_coll_prop, prefix, left_edge_with_prefix, top_QMARK_, empty_QMARK_, terminal_type_QMARK_, left_edge_type_QMARK_, children, nodes_between, prefix_edge_QMARK_, discard_QMARK_, right_edge_type_QMARK_, balanced_range, prefix_container_QMARK_, topmost_cursor, coll_prop, closed_by, error_QMARK_, _BAR_node, balanced_QMARK_, start_edge_type_QMARK_, prefix_container_prop, down_last, prefix_QMARK_, name, same_edge_QMARK_, prefix_container_type_QMARK_, rights, with_prefix, start, tree, closest, cursor, node_prop, from_to, follow_edges, start_edge_QMARK_, highest, embedded_QMARK_, opened_by, coll_QMARK_, down, type, terminal_cursor, within_QMARK_, inner_span, depth, prefix_type_QMARK_, same_edge_prop, nearest_touching, regexp_QMARK_, top_type_QMARK_, error_type_QMARK_, up_here, ancestor_QMARK_, end_edge_type_QMARK_, right_edge_QMARK_, start_edge_prop, prefix_edge_prop, node_BAR_, left_edge_QMARK_, coll_type_QMARK_, lefts, require_balance_QMARK_, end, prefix_edge_type_QMARK_, within_program_QMARK_, left, end_edge_QMARK_, program_QMARK_, move_toward, eq_QMARK_ }
